@@ -1,13 +1,3 @@
-package Dancer::Plugin::Assets;
-{
-  $Dancer::Plugin::Assets::VERSION = '1.4';
-}
-use URI;
-use Dancer::Plugin;
-use Dancer ":syntax";
-
-use File::Assets;
-
 =head1 NAME
 
 Dancer::Plugin::Assets - Manage and minify .css and .js assets in a Dancer application
@@ -16,20 +6,24 @@ Dancer::Plugin::Assets - Manage and minify .css and .js assets in a Dancer appli
 
 =head3 In your Dancer application
 
- use Dancer::Plugin::Assets "add_asset";
+ use Dancer::Plugin::Assets qw( assets add_asset );
 
 =head3 Sometime during the request ...
 
  get "/index" => sub {
+    ## Include assets by plugin method
     add_asset "/css/beautiful.css";
     add_asset "/css/handlebars.js";
+
+    ## Include assets by assets object
+    assets->include( "/css/main.css" );
+    assets->include( "/js/something.js" );
  };
 
 =head3 Then, in your .tt, print css tags at <head>, print js tags after body
 
   <html>
     <head><title>[% title %]</title>
-    [% add_asset("/js/jquery.js") %]
     [% css_tags %]
     </head>
     <body>
@@ -37,13 +31,14 @@ Dancer::Plugin::Assets - Manage and minify .css and .js assets in a Dancer appli
     [% js_tags %]
   </html>
 
-=head3 Or you want all css and js tags inside <head>
+=head3 Or you want to add css and js and print them all in template file inside <head>
 
   <html>
     <head><title>[% title %]</title>
-    [% add_asset("/js/jquery.js") %]
-    [% add_asset("/js/handlebars.js") %]
-    [% add_asset("/css/beautiful.css") %]
+    [% add_asset("/js/jquery.js")         %]
+    [% add_asset("/js/handlebars.js")     %]
+    [% add_asset("/css/beautiful.css")    %]
+    [% CALL assets.include("/js/foo.js")  %]
     [% css_and_js_tags || js_and_css_tags %]
     </head>
     <body>
@@ -52,13 +47,13 @@ Dancer::Plugin::Assets - Manage and minify .css and .js assets in a Dancer appli
 
 =head1 DESCRIPTION
 
-Dancer::Plugin::Assets integrates File::Assets into your Dancer application. Essentially, it provides a unified way to include .css and .js assets from different parts of your program. When you're done processing a request, you can use assets)->export() or [% css_and_js_tags %] to generate HTML or var("assets")->exports() to get a list of assets.
+Dancer::Plugin::Assets integrates File::Assets into your Dancer application. Essentially, it provides a unified way to include .css and .js assets from different parts of your program. When you're done processing a request, you can use assets->export() or [% css_and_js_tags %] to generate HTML or assets->exports() to get a list of assets.
 
 D::P::Assets will also handle .css files of different media types properly.
 
-In addition, D::P::Assets includes support for minification via YUI compressor, JavaScript::Minifier, CSS::Minifier, JavaScript::Minifier::XS, and CSS::Minifier::XS
+In addition, D::P::Assets includes support for minification via YUI compressor, L<JavaScript::Minifier>, L<CSS::Minifier>, L<JavaScript::Minifier::XS>, and L<CSS::Minifier::XS>
 
-Note that Dancer::Plugin::Assets does not serve files directly, it will work with Static::Simple or whatever static-file-serving mechanism you're using.
+Note that Dancer::Plugin::Assets does not serve files directly, it will work with L<Static::Simple> or whatever static-file-serving mechanism you're using.
 
 =head1 USEAGE
 
@@ -109,15 +104,45 @@ Here is an example configuration: ( All the value are set by default )
         Assets:
             base_dir: "/public"
             output_dir: "static/%n%-l.%e"
-            minify: 1
             minified_name: "minified"
+            minify: 1
 
-=head1 METHODS
+=head1 METHODS IN ROUTE CODE
 
 =head2 assets
 
 Return L<File::Assets> object that exists throughout the lifetime of the request
 
+=head2 add_asset
+
+same as sub { assets->include( shift ); return undef }
+
+=head1 METHODS IN TT
+
+=head2 [% assets %]
+
+Return L<File::Assets> object that exists throughout the lifetime of the request
+
+=head2 [% add_asset %]
+
+same as [% CALL assets.include( "file..." ) %]
+
+=head2 [% css_tags %]
+
+return tags of css in html
+
+=head2 [% js_tags %]
+
+return tags of javascript in html
+
+=head2 [% css_and_js_tags %]
+
+return tags in this order of css and javascript in html
+
+=head2 [% js_and_css_tags %]
+
+return tags in this order of javascript and css in html
+
 =head1 AUTHOR
 
 Michael Vu, C<< <micvu at cpan.org> >>
@@ -183,6 +208,15 @@ under the same terms as Perl itself.
 
 =cut
 
+package Dancer::Plugin::Assets;
+{
+  $Dancer::Plugin::Assets::VERSION = '1.5';
+}
+use URI;
+use Dancer::Plugin;
+use Dancer ":syntax";
+use File::Assets;
+
 register assets              => \&_assets;
 register add_asset           => \&_include;
 register_plugin for_versions => [ 1, 2 ];
